@@ -26,6 +26,7 @@
 
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
+
 #include <libgnomeui/gnome-window-icon.h>
 
 #include "manager.h"
@@ -93,10 +94,10 @@ ignore (int sig)
 static void
 set_lang (void)
 {
-  char *gdm_lang;
-  char *env_string;
-  char *short_lang;
-  char *p;
+  const char *gdm_lang;
+  char       *env_string;
+  char       *short_lang;
+  char       *p;
 
   gdm_lang = g_getenv("GDM_LANG");
   if (gdm_lang)
@@ -132,8 +133,9 @@ main (int argc, char *argv[])
   set_lang();
 
   /* Initialize the i18n stuff */
-  bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-  textdomain (PACKAGE);
+  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
 
   /* We do this as a separate executable, and do it first so that we
    * make sure we have a absolutely clean setup if the user blows
@@ -141,13 +143,13 @@ main (int argc, char *argv[])
    */
   system ("gnome-login-check");
 
-  gnomelib_init ("gnome-session", VERSION);
   initialize_ice ();
   fprintf (stderr, "SESSION_MANAGER=%s\n", getenv ("SESSION_MANAGER"));
   gnome_client_disable_master_connection ();
   gnome_init_with_popt_table("gnome-session", VERSION, argc, argv, options, 0,
 			     &ctx);
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-session.png");
+
   poptFreeContext(ctx);
 
   /* Make sure children see the right value for DISPLAY.  This is
@@ -182,7 +184,7 @@ main (int argc, char *argv[])
   if(failsafe)
 	session_name = FAILSAFE_SESSION;
   
-  session_name_env = g_strconcat ("GNOME_SESSION_NAME=", g_strdup (session_name), NULL);
+  session_name_env = g_strconcat ("GNOME_DESKTOP_SESSION_ID=", g_strdup (session_name), NULL);
   putenv (session_name_env);
   the_session = read_session (session_name);
 
