@@ -6,50 +6,51 @@
  */
 
 #include "config.h"
+#include "panel-marshal.h"
 #include "aligned-widget.h"
 #include "panel_config_global.h"
 #include "foobar-widget.h"
 #include "multiscreen-stuff.h"
-
-extern GlobalConfig global_config;
-extern int pw_minimized_size;
+#include "panel-typebuiltins.h"
 
 static void aligned_pos_class_init (AlignedPosClass *klass);
-static void aligned_pos_init (AlignedPos *pos);
+static void aligned_pos_instance_init (AlignedPos *pos);
 
 static void aligned_pos_set_pos (BasePWidget *basep,
 				 int x, int y,
-				 int w, int h);
+				 int w, int h,
+				 gboolean force);
 static void aligned_pos_get_pos (BasePWidget *basep,
 				 int *x, int *y,
 				 int w, int h);
 
 static void aligned_pos_show_hide_left (BasePWidget *basep);
 static void aligned_pos_show_hide_right (BasePWidget *basep);
-static BorderPosClass *parent_class;
+static BorderPosClass *aligned_pos_parent_class;
 
-GtkType
+GType
 aligned_pos_get_type (void)
 {
-	static GtkType aligned_pos_type = 0;
+	static GType object_type = 0;
 
-	if (aligned_pos_type == 0) {
-		GtkTypeInfo aligned_pos_info = {
-			"AlignedPos",
-			sizeof (AlignedPos),
-			sizeof (AlignedPosClass),
-			(GtkClassInitFunc) aligned_pos_class_init,
-			(GtkObjectInitFunc) aligned_pos_init,
-			NULL,
-			NULL,
-			NULL
+	if (object_type == 0) {
+		static const GTypeInfo object_info = {
+                    sizeof (AlignedPosClass),
+                    (GBaseInitFunc)         NULL,
+                    (GBaseFinalizeFunc)     NULL,
+                    (GClassInitFunc)        aligned_pos_class_init,
+                    NULL,                   /* class_finalize */
+                    NULL,                   /* class_data */
+                    sizeof (AlignedPos),
+                    0,                      /* n_preallocs */
+                    (GInstanceInitFunc)     aligned_pos_instance_init
 		};
 
-		aligned_pos_type = gtk_type_unique (TYPE_BORDER_POS,
-						    &aligned_pos_info);
+		object_type = g_type_register_static (BORDER_TYPE_POS, "AlignedPos", &object_info, 0);
+		aligned_pos_parent_class = g_type_class_ref (BORDER_TYPE_POS);
 	}
 			       
-	return aligned_pos_type;
+	return object_type;
 }
 
 enum {
@@ -62,23 +63,21 @@ static guint aligned_pos_signals[LAST_SIGNAL] = { 0 };
 static void
 aligned_pos_class_init (AlignedPosClass *klass)
 {
-	BasePPosClass *pos_class = BASEP_POS_CLASS(klass);
-	GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
-	parent_class = gtk_type_class(TYPE_BORDER_POS);
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	BasePPosClass *pos_class = BASEP_POS_CLASS (klass);
+
 	
 	aligned_pos_signals[ALIGN_CHANGE_SIGNAL] =
-		gtk_signal_new ("align_change",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (AlignedPosClass,
-						   align_change),
-				gtk_marshal_NONE__ENUM,
-				GTK_TYPE_NONE,
-				1, GTK_TYPE_ENUM);
-
-	gtk_object_class_add_signals (object_class,
-				      aligned_pos_signals,
-				      LAST_SIGNAL);
+		g_signal_new ("align_change",
+			      G_SIGNAL_RUN_LAST,
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_STRUCT_OFFSET (AlignedPosClass, align_change),
+			      NULL,
+			      NULL,
+			      panel_marshal_VOID__ENUM,
+			      G_TYPE_NONE,
+			      1, 
+			      PANEL_TYPE_ALIGNED_ALIGNMENT);
 
 	pos_class->set_pos = aligned_pos_set_pos;
 	pos_class->get_pos = aligned_pos_get_pos;
@@ -89,71 +88,83 @@ aligned_pos_class_init (AlignedPosClass *klass)
 }
 
 static void
-aligned_pos_init (AlignedPos *pos) { }
+aligned_pos_instance_init (AlignedPos *pos) {
+	/* Does nothing */
+}
 
 static void
 aligned_pos_set_pos (BasePWidget *basep,
 		     int x, int y,
-		     int w, int h)
+		     int w, int h,
+		     gboolean force)
 {
-	int minx, miny, maxx, maxy;
+	int innerx, innery;
+	int screen_width, screen_height;
 
 	BorderEdge newpos = BORDER_POS(basep->pos)->edge;
 	AlignedAlignment newalign = ALIGNED_POS(basep->pos)->align;
 
-	gdk_window_get_geometry (GTK_WIDGET(basep)->window,
-				 &minx, &miny, &maxx, &maxy, NULL);
-	gdk_window_get_origin (GTK_WIDGET(basep)->window, &minx, &miny);
-	maxx += minx;
-	maxy += miny;
-	if (x >= minx &&
-	    x <= maxx &&
-	    y >= miny &&
-	    y <= maxy)
- 	        return;
+	if ( ! force) {
+		int minx, miny, maxx, maxy;
+		gdk_window_get_geometry (GTK_WIDGET(basep)->window,
+					 &minx, &miny, &maxx, &maxy, NULL);
+		gdk_window_get_origin (GTK_WIDGET(basep)->window, &minx, &miny);
+		maxx += minx;
+		maxy += miny;
+		if (x >= minx &&
+		    x <= maxx &&
+		    y >= miny &&
+		    y <= maxy)
+			return;
+	}
+	
+	innerx = x - multiscreen_x (basep->screen);
+	innery = y - multiscreen_y (basep->screen);
+	screen_width = multiscreen_width (basep->screen);
+	screen_height = multiscreen_height (basep->screen);
 
 	/*if in the inner 1/3rd, don't change to avoid fast flickery
 	  movement*/
-	if ( x>(gdk_screen_width()/3) &&
-	     x<(2*gdk_screen_width()/3) &&
-	     y>(gdk_screen_height()/3) &&
-	     y<(2*gdk_screen_height()/3))
+	if ( innerx > (screen_width / 3) &&
+	     innerx < (2*screen_width / 3) &&
+	     innery > (screen_height / 3) &&
+	     innery < (2*screen_height / 3))
 		return;
 
-	if ((x) * gdk_screen_height() > y * gdk_screen_width() ) {
-		if(gdk_screen_height() * (gdk_screen_width()-(x)) >
-		   y * gdk_screen_width() ) {
+	if (innerx * screen_height > innery * screen_width ) {
+		if (screen_height * (screen_width-innerx) >
+		    innery * screen_width ) {
 			newpos = BORDER_TOP;
-			if(x<gdk_screen_width()/3)
+			if (innerx < screen_width/3)
 				newalign = ALIGNED_LEFT;
-			else if (x<2*gdk_screen_width()/3)
+			else if (innerx < 2*screen_width/3)
 				newalign = ALIGNED_CENTER;
 			else
 				newalign = ALIGNED_RIGHT;
 		} else {
 			newpos = BORDER_RIGHT;
-			if(y<gdk_screen_height()/3)
+			if (innery < screen_height/3)
 				newalign = ALIGNED_LEFT;
-			else if (y<2*gdk_screen_height()/3)
+			else if (innery < 2*screen_height/3)
 				newalign = ALIGNED_CENTER;
 			else
 				newalign = ALIGNED_RIGHT;
 		}
 	} else {
-		if(gdk_screen_height() * (gdk_screen_width()-(x)) >
-		   y * gdk_screen_width() ) {
+		if (screen_height * (screen_width-innerx) >
+		    innery * screen_width ) {
 			newpos = BORDER_LEFT;
-			if(y<gdk_screen_height()/3)
+			if (innery < screen_height/3)
 				newalign = ALIGNED_LEFT;
-			else if(y<2*gdk_screen_height()/3)
+			else if (innery < 2*screen_height/3)
 				newalign = ALIGNED_CENTER;
 			else
 				newalign = ALIGNED_RIGHT;
 		} else {
 			newpos = BORDER_BOTTOM;
-			if(x<gdk_screen_width()/3)
+			if (innerx < screen_width/3)
 				newalign = ALIGNED_LEFT;
-			else if(x<2*gdk_screen_width()/3)
+			else if (innerx < 2*screen_width/3)
 				newalign = ALIGNED_CENTER;
 			else
 				newalign = ALIGNED_RIGHT;
@@ -195,8 +206,8 @@ aligned_pos_get_pos (BasePWidget *basep, int *x, int *y,
 		break;
 	case BORDER_RIGHT:
 		*x = multiscreen_width(basep->screen) - w;
-		basep_border_get (BORDER_TOP, NULL, NULL, &a);
-		basep_border_get (BORDER_BOTTOM, NULL, NULL, &b);
+		basep_border_get (basep->screen, BORDER_TOP, NULL, NULL, &a);
+		basep_border_get (basep->screen, BORDER_BOTTOM, NULL, NULL, &b);
 		switch (ALIGNED_POS(basep->pos)->align) {
 		case ALIGNED_LEFT:
 			*y = foobar_widget_get_height (basep->screen) + a;
@@ -210,8 +221,8 @@ aligned_pos_get_pos (BasePWidget *basep, int *x, int *y,
 		}
 		break;
 	case BORDER_LEFT:
-		basep_border_get (BORDER_TOP, &a, NULL, NULL);
-		basep_border_get (BORDER_BOTTOM, &b, NULL, NULL);
+		basep_border_get (basep->screen, BORDER_TOP, &a, NULL, NULL);
+		basep_border_get (basep->screen, BORDER_BOTTOM, &b, NULL, NULL);
 		switch (ALIGNED_POS(basep->pos)->align) {
 		case ALIGNED_LEFT:
 			*y = foobar_widget_get_height (basep->screen) + a;
@@ -229,7 +240,7 @@ aligned_pos_get_pos (BasePWidget *basep, int *x, int *y,
 	*x += multiscreen_x (basep->screen);
 	*y += multiscreen_y (basep->screen);
 
-	basep_border_queue_recalc ();
+	basep_border_queue_recalc (basep->screen);
 }
 
 static void
@@ -273,6 +284,7 @@ aligned_pos_show_hide_right (BasePWidget *basep)
 
 void
 aligned_widget_change_params (AlignedWidget *aligned,
+			      int screen,
 			      AlignedAlignment align,
 			      BorderEdge edge,
 			      int sz,
@@ -293,18 +305,25 @@ aligned_widget_change_params (AlignedWidget *aligned,
 
 	if (pos->align != align) {
 		pos->align = align;
-		gtk_signal_emit (GTK_OBJECT (pos),
-				 aligned_pos_signals[ALIGN_CHANGE_SIGNAL],
-				 align);
+		g_signal_emit (G_OBJECT (pos),
+			       aligned_pos_signals[ALIGN_CHANGE_SIGNAL],
+			       0, align);
 	}
 
 	border_widget_change_params (BORDER_WIDGET (aligned),
-				     edge, sz, mode, state,
-				     level, avoid_on_maximize,
+				     screen,
+				     edge,
+				     sz,
+				     mode,
+				     state,
+				     level,
+				     avoid_on_maximize,
 				     hidebuttons_enabled,
 				     hidebutton_pixmaps_enabled,
-				     back_type, pixmap_name,
-				     fit_pixmap_bg, strech_pixmap_bg,
+				     back_type,
+				     pixmap_name,
+				     fit_pixmap_bg,
+				     strech_pixmap_bg,
 				     rotate_pixmap_bg,
 				     back_color);
 }
@@ -321,7 +340,9 @@ aligned_widget_change_align (AlignedWidget *aligned,
 	if (pos->align == align)
 		return;
 
-	aligned_widget_change_params (aligned, align,
+	aligned_widget_change_params (aligned,
+				      basep->screen,
+				      align,
 				      BORDER_POS (pos)->edge,
 				      panel->sz, basep->mode,
 				      basep->state,
@@ -345,8 +366,12 @@ aligned_widget_change_align_edge (AlignedWidget *aligned,
 	BasePWidget *basep = BASEP_WIDGET (aligned);
 	PanelWidget *panel = PANEL_WIDGET (basep->panel);
 
-	aligned_widget_change_params (aligned, align, edge,
-				      panel->sz, basep->mode,
+	aligned_widget_change_params (aligned,
+				      basep->screen,
+				      align,
+				      edge,
+				      panel->sz,
+				      basep->mode,
 				      basep->state,
 				      basep->level,
 				      basep->avoid_on_maximize,
@@ -361,7 +386,8 @@ aligned_widget_change_align_edge (AlignedWidget *aligned,
 }
 				 
 GtkWidget *
-aligned_widget_new (AlignedAlignment align,
+aligned_widget_new (int screen,
+		    AlignedAlignment align,
 		    BorderEdge edge,
 		    BasePMode mode,
 		    BasePState state,
@@ -377,22 +403,28 @@ aligned_widget_new (AlignedAlignment align,
 		    gboolean rotate_pixmap_bg,
 		    GdkColor *back_color)
 {
-	AlignedWidget *aligned = gtk_type_new (TYPE_ALIGNED_WIDGET);
-	AlignedPos *pos = gtk_type_new (TYPE_ALIGNED_POS);
+	AlignedWidget *aligned = gtk_type_new (ALIGNED_TYPE_WIDGET);
+	AlignedPos *pos = gtk_type_new (ALIGNED_TYPE_POS);
 	pos->align = align;
 
 	BASEP_WIDGET (aligned)->pos = BASEP_POS (pos);
 
 	border_widget_construct (BORDER_WIDGET (aligned),
+				 screen,
 				 edge, 
-				 TRUE, FALSE,
-				 sz, mode, state,
+				 TRUE,
+				 FALSE,
+				 sz,
+				 mode,
+				 state,
 				 level,
 				 avoid_on_maximize,
 				 hidebuttons_enabled,
 				 hidebutton_pixmaps_enabled,
-				 back_type, back_pixmap,
-				 fit_pixmap_bg, strech_pixmap_bg,
+				 back_type,
+				 back_pixmap,
+				 fit_pixmap_bg,
+				 strech_pixmap_bg,
 				 rotate_pixmap_bg,
 				 back_color);
 
