@@ -8,18 +8,22 @@
 #include "config.h"
 
 #include "border-widget.h"
+#include "panel-marshal.h"
 #include "panel_config_global.h"
+#include "multiscreen-stuff.h"
+#include "panel-typebuiltins.h"
+
+#undef BORDER_WIDGET_DEBUG
 
 extern GlobalConfig global_config;
-extern int pw_minimized_size;
 
 static void border_pos_class_init (BorderPosClass *klass);
-static void border_pos_init (BorderPos *pos);
+static void border_pos_instance_init (BorderPos *pos);
 
 static void border_pos_set_hidebuttons (BasePWidget *basep);
-static PanelOrientType border_pos_get_applet_orient (BasePWidget *basep);
+static PanelOrient border_pos_get_applet_orient (BasePWidget *basep);
 
-static PanelOrientType border_pos_get_hide_orient (BasePWidget *basep);
+static PanelOrient border_pos_get_hide_orient (BasePWidget *basep);
 
 static void border_pos_get_menu_pos (BasePWidget *basep,
 				     GtkWidget *widget,
@@ -33,28 +37,31 @@ static void border_pos_show_hide_right (BasePWidget *basep);
 
 static void border_pos_pre_convert_hook (BasePWidget *basep);
 
-static BasePPosClass *parent_class;
+static BasePPosClass *border_pos_parent_class;
 
-GtkType
+GType
 border_pos_get_type (void)
 {
-	static GtkType border_pos_type = 0;
-
-	if (!border_pos_type) {
-		GtkTypeInfo border_pos_info = {
-			"BorderPos",
-			sizeof (BorderPos),
+	static GType object_type = 0;
+	if (object_type == 0) {
+		static const GTypeInfo object_info = {
 			sizeof (BorderPosClass),
-			(GtkClassInitFunc) border_pos_class_init,
-			(GtkObjectInitFunc) border_pos_init,
-			NULL, NULL
+			(GBaseInitFunc)		NULL,
+			(GBaseFinalizeFunc) 	NULL,
+			(GClassInitFunc)	border_pos_class_init,
+			NULL,			/* class_finalize */
+			NULL,			/* class_data */
+			sizeof (BorderPos),
+			0,			/* n_preallocs */
+			(GInstanceInitFunc)	border_pos_instance_init
 		};
 
-		border_pos_type = gtk_type_unique (TYPE_BASEP_POS,
-						   &border_pos_info);
+		object_type = g_type_register_static (BASEP_TYPE_POS,
+						      "BorderPos", &object_info, 0);
+		border_pos_parent_class = g_type_class_ref (BASEP_TYPE_POS);
 	}
 
-	return border_pos_type;
+	return object_type;
 }
 
 enum {
@@ -67,25 +74,22 @@ static guint border_pos_signals[LAST_SIGNAL] = { 0 };
 static void
 border_pos_class_init (BorderPosClass *klass)
 {
-	GtkObjectClass *object_class = GTK_OBJECT_CLASS(klass);
+	GObjectClass *object_class = G_OBJECT_CLASS(klass);
 	BasePPosClass *pos_class = BASEP_POS_CLASS(klass);
 
-	parent_class = gtk_type_class(TYPE_BASEP_POS);
 
 	/* set up signals */
 	border_pos_signals[EDGE_CHANGE_SIGNAL] =
-		gtk_signal_new("edge_change",
-			       GTK_RUN_LAST,
-			       object_class->type,
-			       GTK_SIGNAL_OFFSET(BorderPosClass,
-						 edge_change),
-			       gtk_marshal_NONE__ENUM,
-			       GTK_TYPE_NONE, 1,
-			       GTK_TYPE_ENUM);
-
-	gtk_object_class_add_signals (object_class, 
-				      border_pos_signals,
-				      LAST_SIGNAL);
+		g_signal_new ("edge_change",
+			     G_TYPE_FROM_CLASS (object_class), 
+			     G_SIGNAL_RUN_LAST,
+			     G_STRUCT_OFFSET (BorderPosClass, edge_change),
+			     NULL,
+			     NULL,
+			     panel_marshal_VOID__ENUM,
+			     G_TYPE_NONE,
+			     1,
+			     PANEL_TYPE_BORDER_EDGE);
 
 	/* fill out the virtual funcs */
 	pos_class->set_hidebuttons = border_pos_set_hidebuttons;
@@ -98,10 +102,11 @@ border_pos_class_init (BorderPosClass *klass)
 	pos_class->south_clicked = pos_class->east_clicked =
 		border_pos_show_hide_right;
 	pos_class->pre_convert_hook = border_pos_pre_convert_hook;
+
 }
 
 static void
-border_pos_init (BorderPos *pos)
+border_pos_instance_init (BorderPos *pos)
 {
 	pos->edge = BORDER_TOP;
 }
@@ -122,21 +127,21 @@ border_pos_set_hidebuttons (BasePWidget *basep)
 	}
 }
 
-static PanelOrientType
+static PanelOrient
 border_pos_get_applet_orient (BasePWidget *basep)
 {
 	BorderPos *pos = BORDER_POS(basep->pos);
 	
 	switch (pos->edge) {
-	case BORDER_TOP: return ORIENT_DOWN;
-	case BORDER_RIGHT: return ORIENT_LEFT;
-	case BORDER_BOTTOM: return ORIENT_UP;
-	case BORDER_LEFT: return ORIENT_RIGHT;
-	default: return ORIENT_UP;		
+	case BORDER_TOP: return PANEL_ORIENT_DOWN;
+	case BORDER_RIGHT: return PANEL_ORIENT_LEFT;
+	case BORDER_BOTTOM: return PANEL_ORIENT_UP;
+	case BORDER_LEFT: return PANEL_ORIENT_RIGHT;
+	default: return PANEL_ORIENT_UP;		
 	}
 }
 
-static PanelOrientType 
+static PanelOrient 
 border_pos_get_hide_orient (BasePWidget *basep)
 {
 	BorderPos *pos = BORDER_POS (basep->pos);
@@ -145,27 +150,53 @@ border_pos_get_hide_orient (BasePWidget *basep)
 	switch (basep->state) {
 	case BASEP_AUTO_HIDDEN:
 		switch (pos->edge) {
-		case BORDER_TOP: return ORIENT_UP;
-		case BORDER_RIGHT: return ORIENT_RIGHT;
-		case BORDER_LEFT: return ORIENT_LEFT;
-		case BORDER_BOTTOM: return ORIENT_DOWN;
+		case BORDER_TOP: return PANEL_ORIENT_UP;
+		case BORDER_RIGHT: return PANEL_ORIENT_RIGHT;
+		case BORDER_LEFT: return PANEL_ORIENT_LEFT;
+		case BORDER_BOTTOM: return PANEL_ORIENT_DOWN;
 		}
 		g_assert_not_reached ();
 		break;
 	case BASEP_HIDDEN_LEFT:
 		return (panel->orient == PANEL_HORIZONTAL)
-			? ORIENT_LEFT : ORIENT_UP;
+			? PANEL_ORIENT_LEFT : PANEL_ORIENT_UP;
 	case BASEP_HIDDEN_RIGHT:
 		return (panel->orient == PANEL_HORIZONTAL)
-			? ORIENT_RIGHT : ORIENT_DOWN;
+			? PANEL_ORIENT_RIGHT : PANEL_ORIENT_DOWN;
 	default:
 		g_assert_not_reached ();
 		break;
 	}
 	g_assert_not_reached ();
-	return ORIENT_LEFT;
+	return PANEL_ORIENT_LEFT;
 }
 
+#ifdef BORDER_WIDGET_DEBUG
+static void
+border_pos_debug_print_edge (BorderEdge edge)
+{
+	g_print ("BorderEdge = ");
+
+	switch (edge) {
+	case BORDER_TOP:
+		g_print ("(top)\n");
+		break;
+	case BORDER_RIGHT:
+		g_print ("(right)\n");
+		break;
+	case BORDER_BOTTOM:
+		g_print ("(bottom)\n");
+		break;
+	case BORDER_LEFT:
+		g_print ("(left)\n");
+		break;
+	default:
+		g_assert_not_reached ();
+		break;
+	}
+}
+#endif /* BORDER_WIDGET_DEBUG */
+
 static void
 border_pos_get_menu_pos (BasePWidget *basep,
 			 GtkWidget *widget,
@@ -174,6 +205,11 @@ border_pos_get_menu_pos (BasePWidget *basep,
 			 int wx, int wy,
 			 int ww, int wh)
 {
+
+#ifdef BORDER_WIDGET_DEBUG
+	border_pos_debug_print_edge (BORDER_POS(basep->pos)->edge);
+#endif /* BORDER_WIDGET_DEBUG */
+
 	switch (BORDER_POS(basep->pos)->edge) {
 	case BORDER_TOP:
 		*x += wx;
@@ -191,11 +227,15 @@ border_pos_get_menu_pos (BasePWidget *basep,
 		*x = wx + ww;
 		*y += wy;
 		break;
+	default:
+		g_assert_not_reached ();
+		break;
 	}
 }
 
 void
 border_widget_change_params (BorderWidget *border,
+			     int screen,
 			     BorderEdge edge,
 			     int sz,
 			     BasePMode mode,
@@ -221,20 +261,25 @@ border_widget_change_params (BorderWidget *border,
 
 	if (edge != BORDER_POS (border->pos)->edge) {	
 		BORDER_POS(border->pos)->edge = edge;
-		gtk_signal_emit (GTK_OBJECT (border->pos),
-				 border_pos_signals[EDGE_CHANGE_SIGNAL],
-				 edge);
+		g_signal_emit (G_OBJECT (border->pos),
+			       border_pos_signals[EDGE_CHANGE_SIGNAL],
+			       0, edge);
 	}
 
 	basep_widget_change_params (BASEP_WIDGET (border),
+				    screen,
 				    new_orient,
-				    sz, mode, state,
-				    level, avoid_on_maximize,
+				    sz,
+				    mode,
+				    state,
+				    level,
+				    avoid_on_maximize,
 				    hidebuttons_enabled,
 				    hidebutton_pixmaps_enabled,
 				    back_type,
 				    pixmap_name,
-				    fit_pixmap_bg, strech_pixmap_bg,
+				    fit_pixmap_bg,
+				    strech_pixmap_bg,
 				    rotate_pixmap_bg,
 				    back_color);
 }
@@ -285,8 +330,10 @@ border_widget_change_edge (BorderWidget *border, BorderEdge edge)
 	
 	if (BORDER_POS (border->pos)->edge == edge)
 		return;
-	
-	border_widget_change_params (border, edge,
+
+	border_widget_change_params (border,
+				     basep->screen,
+				     edge,
 				     panel->sz,
 				     basep->mode,
 				     basep->state,
@@ -300,11 +347,11 @@ border_widget_change_edge (BorderWidget *border, BorderEdge edge)
 				     panel->strech_pixmap_bg,
 				     panel->rotate_pixmap_bg,
 				     &panel->back_color);
-	
 }
 
 GtkWidget *
 border_widget_construct (BorderWidget *border,
+			 int screen,
 			 BorderEdge edge,
 			 gboolean packed,
 			 gboolean reverse_arrows,
@@ -337,6 +384,7 @@ border_widget_construct (BorderWidget *border,
 	basep_widget_construct (basep,
 				packed,
 				reverse_arrows,
+				screen,
 				orient,
 				sz,
 				mode,
