@@ -11,20 +11,20 @@
 #include "basep-widget.h"
 #include "drawer.h"
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
-#define TYPE_DRAWER_POS            (drawer_pos_get_type ())
-#define DRAWER_POS(o)              (GTK_CHECK_CAST ((o), TYPE_DRAWER_POS, DrawerPos))
-#define DRAWER_POS_CLASS(k)        (GTK_CHECK_CLASS_CAST ((k), DRAWER_POS_TYPE, DrawerPosClass))
-#define IS_DRAWER_POS(o)           (GTK_CHECK_TYPE ((o), TYPE_DRAWER_POS))
-#define IS_DRAWER_POS_CLASS(k)     (GTK_CHECK_CLASS_TYPE ((k), TYPE_DRAWER_POS))
+#define DRAWER_TYPE_POS			(drawer_pos_get_type ())
+#define DRAWER_POS(object)              (G_TYPE_CHECK_INSTANCE_CAST ((object), DRAWER_TYPE_POS, DrawerPos))
+#define DRAWER_POS_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST ((klass), DRAWER_TYPE_POS, DrawerPosClass))
+#define DRAWER_IS_POS(object)           (G_TYPE_CHECK_INSTANCE_TYPE ((object), DRAWER_TYPE_POS))
+#define DRAWER_IS_POS_CLASS(k)     	(G_TYPE_CHECK_CLASS_TYPE ((klass), DRAWER_TYPE_POS))
 
-#define TYPE_DRAWER_WIDGET         (TYPE_BASEP_WIDGET)
-#define DRAWER_WIDGET(o)           (BASEP_WIDGET(o))
-#define DRAWER_WIDGET_CLASS(k)     (BASEP_WIDGET_CLASS(k))
-#define IS_DRAWER_WIDGET(o)        (IS_BASEP_WIDGET(o) && IS_DRAWER_POS(BASEP_WIDGET(o)->pos))
+#define DRAWER_TYPE_WIDGET         	(BASEP_TYPE_WIDGET)
+#define DRAWER_WIDGET(object)          	(BASEP_WIDGET(object))
+#define DRAWER_WIDGET_CLASS(klass)      (BASEP_WIDGET_CLASS(klass))
+#define DRAWER_IS_WIDGET(object)        (BASEP_IS_WIDGET(object) && DRAWER_IS_POS(BASEP_WIDGET(object)->pos))
 /* this is not reliable */
-#define IS_DRAWER_WIDGET_CLASS(k)  (IS_BASEP_WIDGET_CLASS(k))
+#define DRAWER_IS_WIDGET_CLASS(klass)	(BASEP_IS_WIDGET_CLASS(klass))
 
 typedef BasePWidget            DrawerWidget;
 typedef BasePWidgetClass       DrawerWidgetClass;
@@ -36,7 +36,7 @@ struct _DrawerPos {
 	BasePPos pos;
 
 	BasePState temp_hidden;
-	PanelOrientType orient;
+	PanelOrient orient;
 };
 
 struct _DrawerPosClass {
@@ -45,17 +45,20 @@ struct _DrawerPosClass {
 #if 0
 	/* signal */
 	void (*orient_change) (DrawerPos *pos,
-			       PanelOrientType orient);
+			       PanelOrient orient);
 #endif
 };
 
-GtkType drawer_pos_get_type (void) G_GNUC_CONST;
-GtkWidget *drawer_widget_new (PanelOrientType orient,
+GType drawer_pos_get_type (void) G_GNUC_CONST;
+
+GtkWidget *drawer_widget_new (PanelOrient orient,
 			      BasePMode mode,
 			      BasePState state,
+			      BasePLevel level,
+			      gboolean avoid_on_maximize,
 			      int sz,
-			      int hidebuttons_enabled,
-			      int hidebutton_pixmap_enabled,
+			      gboolean hidebuttons_enabled,
+			      gboolean hidebutton_pixmap_enabled,
 			      PanelBackType back_type,
 			      char *back_pixmap,
 			      gboolean fit_pixmap_bg,
@@ -64,12 +67,14 @@ GtkWidget *drawer_widget_new (PanelOrientType orient,
 			      GdkColor *back_color);
 
 void drawer_widget_change_params (DrawerWidget *drawer,
-				  PanelOrientType orient,
+				  PanelOrient orient,
 				  BasePMode mode,
 				  BasePState state,
+				  BasePLevel level,
+				  gboolean avoid_on_maximize,
 				  int sz,
-				  int hidebuttons_enabled,
-				  int hidebutton_pixmap_enabled,
+				  gboolean hidebuttons_enabled,
+				  gboolean hidebutton_pixmap_enabled,
 				  PanelBackType back_type,
 				  char *back_pixmap,
 				  gboolean fit_pixmap_bg,
@@ -78,7 +83,7 @@ void drawer_widget_change_params (DrawerWidget *drawer,
 				  GdkColor *back_color);
 
 void drawer_widget_change_orient (DrawerWidget *drawer,
-				  PanelOrientType orient);
+				  PanelOrient orient);
 
 void drawer_widget_restore_state (DrawerWidget *drawer);
 
@@ -90,6 +95,6 @@ void		drawer_widget_close_drawer	(DrawerWidget *panel,
 
 void            drawer_widget_restore_state     (DrawerWidget *drawer);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif
