@@ -3,14 +3,18 @@
 #include <X11/keysym.h>
 #include <gdk/gdkx.h>
 #include <gdk/gdk.h>
+
+#include <libgnome/libgnome.h>
+
 #include "global-keys.h"
+
 #include "applet.h"
-#include "panel-include.h"
 #include "gnome-run.h"
+#include "panel.h"
+#include "panel-util.h"
 #include "panel_config_global.h"
 
 extern GlobalConfig global_config;
-extern GSList *panel_list;
 extern GSList *panels;
 
 #define N_BITS 32 /*all modifier masks fit into it */
@@ -252,7 +256,7 @@ panel_global_keys_filter (GdkXEvent *gdk_xevent,
 		panel = panels->data;
 		menu = make_popup_panel_menu (panel);
 		basep = panel->panel_parent;
-		if (IS_BASEP_WIDGET(basep)) {
+		if (BASEP_IS_WIDGET(basep)) {
 			BASEP_WIDGET(basep)->autohide_inhibit = TRUE;
 			basep_widget_autohide (BASEP_WIDGET (basep));
 		}
@@ -266,7 +270,9 @@ panel_global_keys_filter (GdkXEvent *gdk_xevent,
 			return GDK_FILTER_CONTINUE;
 		}
 
+#ifdef FIXME
 		show_run_dialog ();
+#endif
 		return GDK_FILTER_REMOVE;
 	} else if (keycode == screenshot_keycode &&
 		   (state & USED_MODS) == screenshot_state) {
@@ -278,9 +284,10 @@ panel_global_keys_filter (GdkXEvent *gdk_xevent,
 			return GDK_FILTER_CONTINUE;
 		}
 
-		proggie = gnome_is_program_in_path ("gnome-panel-screenshot");
+		proggie = g_find_program_in_path  ("gnome-panel-screenshot");
 		if (proggie == NULL) {
-			panel_error_dialog (_("Can't find the screenshot "
+			panel_error_dialog ("cannot_find_ss_program",
+					    _("Can't find the screenshot "
 					      "program"));
 			return GDK_FILTER_REMOVE;
 		}
@@ -288,7 +295,8 @@ panel_global_keys_filter (GdkXEvent *gdk_xevent,
 		argv[1] = NULL;
 
 		if (gnome_execute_async (g_get_home_dir (), 1, argv)<0)
-			panel_error_dialog (_("Can't execute the screenshot "
+			panel_error_dialog ("cannot_exec_ss_program",
+					    _("Can't execute the screenshot "
 					      "program"));
 
 		g_free (proggie);
@@ -304,9 +312,10 @@ panel_global_keys_filter (GdkXEvent *gdk_xevent,
 			return GDK_FILTER_CONTINUE;
 		}
 
-		proggie = gnome_is_program_in_path ("gnome-panel-screenshot");
+		proggie = g_find_program_in_path  ("gnome-panel-screenshot");
 		if (proggie == NULL) {
-			panel_error_dialog (_("Can't find the screenshot "
+			panel_error_dialog ("cannot_find_ss_program",
+					    _("Can't find the screenshot "
 					      "program"));
 			return GDK_FILTER_REMOVE;
 		}
@@ -315,7 +324,8 @@ panel_global_keys_filter (GdkXEvent *gdk_xevent,
 		argv[2] = NULL;
 
 		if (gnome_execute_async (g_get_home_dir (), 2, argv)<0)
-			panel_error_dialog (_("Can't execute the screenshot "
+			panel_error_dialog ("cannot_exec_ss_program",
+					    _("Can't execute the screenshot "
 					      "program"));
 
 		g_free (proggie);
