@@ -10,11 +10,11 @@
 
 #include <panel-widget.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 void load_logout_applet(PanelWidget *panel, int pos, gboolean exactpos);
 void load_lock_applet(PanelWidget *panel, int pos, gboolean exactpos);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif
