@@ -13,16 +13,15 @@
 
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gnome.h>
 #include "button-widget.h"
 #include "panel-types.h"
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
-#define TYPE_PANEL_WIDGET          (panel_widget_get_type ())
-#define PANEL_WIDGET(obj)          GTK_CHECK_CAST (obj, panel_widget_get_type (), PanelWidget)
-#define PANEL_WIDGET_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, panel_widget_get_type (), PanelWidgetClass)
-#define IS_PANEL_WIDGET(obj)       GTK_CHECK_TYPE (obj, panel_widget_get_type ())
+#define PANEL_TYPE_WIDGET          	(panel_widget_get_type ())
+#define PANEL_WIDGET(object)          	(G_TYPE_CHECK_INSTANCE_CAST ((object), PANEL_TYPE_WIDGET, PanelWidget))
+#define PANEL_WIDGET_CLASS(klass)  	(G_TYPE_CHECK_CLASS_CAST ((klass), PANEL_TYPE_WIDGET, PanelWidgetClass))
+#define PANEL_IS_WIDGET(object)       	(G_TYPE_CHECK_INSTANCE_TYPE ((object), PANEL_TYPE_WIDGET)) 
 
 #define PANEL_MINIMUM_WIDTH 12
 
@@ -91,7 +90,6 @@ struct _PanelWidget
 	GdkColor		back_color;
 	gboolean		inhibit_draw;
 
-	gboolean		no_padding_on_ends;
 	
 	GtkWidget		*master_widget;
 	
@@ -109,10 +107,6 @@ struct _PanelWidget
 						   was set, this is used
 						   for tiling onto the
 						   background */
-	int			x;
-	int			y;
-	int                     width;
-	int                     height;
 };
 
 struct _PanelWidgetClass
@@ -139,7 +133,8 @@ struct _PanelWidgetClass
 				      GtkWidget *applet);
 };
 
-guint		panel_widget_get_type		(void) G_GNUC_CONST;
+GType		panel_widget_get_type		(void) G_GNUC_CONST;
+
 GtkWidget *	panel_widget_new		(gboolean packed,
 						 PanelOrientation orient,
 						 int sz,
@@ -148,7 +143,6 @@ GtkWidget *	panel_widget_new		(gboolean packed,
 						 gboolean fit_pixmap_bg,
 						 gboolean strech_pixmap_bg,
 						 gboolean rotate_pixmap_bg,
-						 gboolean no_padding_on_ends,
 						 GdkColor *back_color);
 /*add an applet to the panel, preferably at position pos, if insert_at_pos
   is on, we REALLY want to insert at the pos given by pos*/
@@ -210,25 +204,12 @@ void		panel_widget_change_params	(PanelWidget *panel,
 						 gboolean fit_pixmap_bg,
 						 gboolean strech_pixmap_bg,
 						 gboolean rotate_pixmap_bg,
-						 gboolean no_padding_on_ends,
 						 GdkColor *back_color);
 
 /* changing parameters (orient only) */
 void		panel_widget_change_orient	(PanelWidget *panel,
 						 PanelOrientation orient);
 
-/*change global params*/
-void		panel_widget_change_global	(int explicit_step,
-						 int auto_step,
-						 int drawer_step,
-						 int minimized_size,
-						 int minimize_delay,
-						 int maximize_delay,
-						 PanelMovementType move_type,
-						 gboolean disable_animations,
-						 int applet_padding,
-						 int applet_border_padding);
-
 void		panel_widget_set_back_pixmap	(PanelWidget *panel,
 						 char *file);
 void		panel_widget_set_back_color	(PanelWidget *panel,
@@ -268,8 +249,6 @@ void panel_widget_get_applet_rgb_bg(PanelWidget *panel,
 
 extern gboolean panel_applet_in_drag;
 
-void 		panel_widget_force_repaint 	(PanelWidget *panel);
-void		panel_widget_setup_translucent_background (PanelWidget	*panel);
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* PANEL_WIDGET_H */
